#
# spec file for package nml
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           nml
Version:        0.7.1
Release:        bp155.1.5
Summary:        NewGRF Meta Language
License:        GPL-2.0-or-later
Group:          Development/Tools/Building
URL:            http://dev.openttdcoop.org/projects/nml
Source:         https://github.com/OpenTTD/nml/releases/download/%{version}/%{name}-%{version}.tar.gz
BuildRequires:  gcc
BuildRequires:  python3-devel
# We need the required packages also on building for regression tests:
BuildRequires:  python3-Pillow
BuildRequires:  python3-ply
BuildRequires:  python3-setuptools
Requires:       python3-Pillow
Requires:       python3-ply
Requires:       python3-setuptools
Provides:       nmlc = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
A tool to compile nml files to grf or nfo files, making newgrf coding easier.

%prep
%setup -q -n %{name}-%{version}

%build
make
make extensions

%install
python3 setup.py install --skip-build --root=%{buildroot} --prefix=%{_prefix}

install -D -m0644 docs/nmlc.1 %{buildroot}%{_mandir}/man1/nmlc.1

#setuptools should not be a requirement on running, so we install the nmlc wrapper from source
install -m0755 nmlc %{buildroot}%{_bindir}/nmlc
# Fix script interpreter
sed -i 's/\/usr\/bin\/env python3/\/usr\/bin\/python3/' %{buildroot}%{_bindir}/nmlc

# The actual python code is not being installed?!?
mkdir -p %{buildroot}%{python3_sitelib}/nml
cp -rp nml/* %{buildroot}%{python3_sitelib}/nml/
# Remove devel file
rm %{buildroot}%{python3_sitelib}/nml/_lz77.c

%files
%defattr(-,root,root,-)
%doc docs/*.txt
%{_bindir}/nmlc
%{_mandir}/man1/nmlc.1*
%{python3_sitearch}/*
%{python3_sitelib}/%{name}/

%changelog
* Sun Dec 11 2022 Dirk Müller <dmueller@suse.com>
- update to 0.7.1:
  * Fix action0properties.py
  * Minor improvements to examples
  * Change: use an array of cargoes for cargo_random_triggers
  * Change: disabled_platforms/length is now bitmask(1-8)>>1
  * Change: replace nearby_tile_platform_type with nearby_tile_tile_type.
  * Fix: Station animation triggers every 250 ticks, not 256.
  * Fix #256: Objects have a 'colour' in var 47.
  * Change: allow any expression for station (purchase_)prepare_layout
  * Update: changelog for 0.7.1
  * Fix: [Actions] release workflow issues
  * More issues in release workflow
* Mon Nov 14 2022 Andrea Manzini <andrea.manzini@suse.com>
- update to 0.7.0
  This release adds the long awaited support for stations.
  Support for NewGRF additions of OpenTTD 13.0:
  - Add: Map seed in patch variable 0x17.
  Support for NewGRF additions of OpenTTD 1.11:
  - Change: provide nml vars for industry var 0x47 - GameScript control status
  Other changes and fixes:
  - Add: show an error if a required property is not set for objects (feature 0F) (#236)
  - Fix: Reject empty arrays of expressions (#224)
  - Fix #209: Cargo 'profit' callback applied a unit conversion, when there was no unit. (#220)
  - Change: adjust sound name constants to match OpenTTD
  - Fix #253: Produce a more efficient NFO code for abs() builtin function (#255)
* Thu Oct 21 2021 Jan Baier <jbaier@suse.com>
- update to 0.6.1
  - Support for NewGRF additions of OpenTTD 12.0:
  - Update: Increase number of OTTD_GUI sprites to 191 (#253)
  - Switches can now be used as functions inside expressions
  - Switches can now define parameters, which are passed by callers for usage inside the switch
  - NML now applies optimisations to switches and chains of switches
  - optimisation and deprecation warnings can be suppressed with nmlc flags, see 'nmlc --help' (#230)
  - Add: rail vehicle property and callback 'curve_speed_mod' (rail vehicle property 0x2E) (#222)
  - Update: Increase number of OTTD_GUI sprites to 186 (#183)
  - Add: Industry spec_flag 'IND_FLAG_DO_NOT_CLAMP_PASSENGER_PRODUCTION' (#183)
  - Add: Vehicle variables 'tile_(supports|powers|is)_(rail|road|tram)type' (#183)
  - Add: Vehicle variable 'tile_has_catenary' (#183)
  - Add: General variable 'inflation', which reports the game setting (#183)
  - Add: Alternative string constants introduced in OpenTTD/OpenTTD#8392 (#176)
  - Add: industry variable for 'town_index' (var 0x41)
  - Add: constants GROUNDSPRITE_GRASS, GROUNDSPRITE_DESERT_2_2, GROUNDSPRITE_GRASS_1_3, GROUNDSPRITE_GRASS_2_3, GROUNDSPRITE_GRASS_3_3
  - Add: builtin functions for round() and sqrt()
  - Add: plural form 14 for Romanian
  - Change: Check that user code doesn't try to use reserved registers (#189)
  - Change: warn when a deprecated constant is used
  - Change: progress display shows input filename when reading files
  - Change: improve error message when invalid features are used
  - Add: More-obvious error for trailing '.' in a string id (#145)
  - Change: Clean up language definitions (#208)
  - Fix #184: Share townname bits when possible (#185)
  - Fix: Compatibility with Pillow 8.1.0 (#182)
  - Fix #180: No proper error message was given, if an unreferenced String was unable to allocate an id (#181)
  - Fix: Access to persistent-storage of towns  (#173)
  - Fix: Don't suppress errors for incorrect `hide_sprite` values (#168)
  - Fix: Remove trailing whitespaces in NFO output (#164)
  - Fix: town_euclidean_dist was returning incorrect value (#206)
  - Fix: rename MAP_TYPE_RECTANGULAR to MAP_TYPE_SQUARE (#201)
  - Fix: LZ77 compatibility with Python 3.9+ (#215, #228)
  - Fix: access to persistent-storage of towns was broken (#173)
  - Fix: use most likely defined position when reporting error (#226)
  - Update: VS generation script syntax (#233)
- remove upstreamed pcx images
* Tue Mar 16 2021 Antoine Belvire <antoine.belvire@opensuse.org>
- Backport corrected pcx images to fix tests with Pillow 8.1.0
  (gh#OpenTTD/nml!188, deb#980641):
  * arctic_railwagons.pcx
  * opengfx_generic_trams1.pcx
  * opengfx_trains_start.pcx
* Fri Jan  1 2021 Matthias Mailänder <mailaender@opensuse.org>
- Update to version 0.5.3
- Drop python-pillow-version.patch
- Drop 0001-Fix-52-time.clock-has-been-removed-in-python-3.8-53.patch
* Tue Mar 24 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add upstream patch to fix the python 3.8 compatibility:
  * 0001-Fix-52-time.clock-has-been-removed-in-python-3.8-53.patch
* Mon May 27 2019 Jon Brightwell <jon@moozaad.co.uk>
- Removed nml-python341.diff - python bug, fixed python upstream (3.4.2rc1).
- Removed nml-0.4.2-pillow.diff - superceded upstream
- added python-pillow-version.patch - fixes incorrect version number query https://github.com/OpenTTD/nml/pull/29
- update to 0.4.5
  - Feature: increase cargo ID range from 32 to 64, to support 64 cargos in OpenTTD 11ab3c4ea2f6a6d29efda8c9ba2af04194621ea7
  - Change: Support more DCxx strings for OpenTTD r27769.
  - Add: Properties for vehicle sprite stack.
  - Add: CB_FLAG_MORE_SPRITES, PALETTE_IDENTITY
  - Add: String command 9A 1E CARGO_NAME.
  - Add: CB_RESULT_IND_NO_TEXT_NO_AMOUNT
  - Codechange: Store textids without offset in string_ranges
  - Fix: String encoding with cases was non-deterministic and resulted in differing md5sums for the NewGRF.
  - Fix: Rearrange order of string id assignment to keep compatibility.
  - Fix: When some IDs depleted, an internal NML error was raised instead of the intended error message.
  - Fix: most_common_refit was reading the wrong bits in var 42; read the write bits and rename it to most_common_cargo_type
    as it's more accurate; also add most_common_cargo_subtype which also reads var 42 and was previously missing
  - Fix: Switch from :r format code to !r conversion flag to avoid crashes.
- 0.4.4 (2016-01-07)
  - Fix/Revert: Stripping one path level is not enough
- 0.4.3 (2016-01-07)
  - Add: prob_map_gen as alternative name for the mapgen industry probability property
  - Fix: Stripping one path level is enough
  - Fix: Compatibility with newer versions of pillow.
  - Fix: Vehicle 'sort' function caused internal error when an empty list was passed.
  - Fix: motion_counter is 24 bits, not 4.
* Sun Nov 15 2015 opensuse@dstoecker.de
- update to 0.4.2
- add fix for new Pillow (nml-0.4.2-pillow.diff) taken from pyglet
  issue 677
* Fri Oct 23 2015 lnussel@suse.de
- lift requirement on python3-devel and add nml-python341.diff to
  fix build on Leap
* Sat Jun  6 2015 mailaender@opensuse.org
- don't run the regression tests twice
- install the man page
- avoid a runtime dependency on setuptools
* Wed May 20 2015 dimstar@opensuse.org
- Add python3-setuptools requires: nml makes use of pkg_resources
  during runtime
  from openttd-opengfx build log:
  /usr/bin/nmlc -c -p DOS --grf ogfxt_toyland.grf ogfxt_toyland.nml
  Traceback (most recent call last):
    File "/usr/bin/nmlc", line 5, in <module>
    from pkg_resources import load_entry_point
    ImportError: No module named 'pkg_resources'
- Manually install the nml directory into python3_sitelib: python
  setup.py forgets to install this, resulting in nmlc not being able
  to be started (failed to import nml).
* Sun Apr 26 2015 mailaender@opensuse.org
- update to 0.4.1 (drops support for Python 2)
  - improved performance and NewGRF support
* Sat Jun 14 2014 mailaender@opensuse.org
- update to 0.3.1 (drops support for Python version 2.5)
* Sat Dec 29 2012 suse@ammler.ch
- update to 0.2.4 (OpenGFX 0.4.6.1)
  (check changelog.txt)
* Sat Oct 27 2012 suse@ammler.ch
- downgrade to 0.2.3
  OpenGFX 0.4.5 builds with NML 0.2.3 only
* Sun Oct 14 2012 suse@ammler.ch
- update to 0.2.4 (bugfix release)
* Fri Mar  2 2012 cfarrell@suse.com
- license update: GPL-2.0+
  No evidence of GPL-2.0 (only) files in the package
* Fri Mar  2 2012 saschpe@suse.de
- Cleaned up macro usage
* Mon Feb 20 2012 suse@ammler.ch
- upstream update 0.2.3
- Add: Action5 for tunnel portals
- Fix: Properly catch out-of-bounds image reads (issue #3666)
- Fix: Character code 0xA0 (NBSP) is used for an up arrow in TTD, so
    don't write it as ascii. Force unicode instead (issue #3643)
* Mon Feb  6 2012 suse@ammler.ch
- upstream update 0.2.2
* Sat Dec 31 2011 suse@ammler.ch
- upstream update 0.2.1
- required for opengfx 0.4
* Sun Jun 19 2011 ammler@openttdcoop.org
- upstream update 0.1.1
- rpmlintrc to suppress python name policy
* Thu Apr 14 2011 ammler@openttdcoop.org
- initial setup
